..
    This file is part of Invenio.
    Copyright (C) 2018-2020 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _getting-started:

Getting started
===============

.. toctree::
   :maxdepth: 2

   overview
   development-environment
   quickstart/index
   getting-help

